@@ -1,9 +1,9 @@
 use crate::{BrowserData, Versions};
 use once_cell::sync::Lazy;
-use std::collections::HashMap;
+use swc_common::collections::AHashMap;
 
-pub(crate) static BUILTINS: Lazy<HashMap<String, Versions>> = Lazy::new(|| {
-    let map: HashMap<_, BrowserData<Option<String>>> =
+pub(crate) static BUILTINS: Lazy<AHashMap<String, Versions>> = Lazy::new(|| {
+    let map: AHashMap<_, BrowserData<Option<String>>> =
         serde_json::from_str(include_str!("builtin.json")).expect("failed to parse json");
 
     map.into_iter()
